sycl: disable Q1_0 in backend and cleanup unused variables (#21807)

This commit is contained in:
Akarshan Biswas
2026-04-13 09:44:58 +08:00
committed by GitHub
parent 82764d8f40
commit 873c825611
6 changed files with 18 additions and 12 deletions
+1 -1
View File
@@ -488,7 +488,7 @@ static void dequantize_row_nvfp4_sycl(const void * vx, dst_t * y, const int64_t
const int nb = k / QK_NVFP4;
stream->parallel_for(
sycl::nd_range<3>(sycl::range<3>(1, 1, nb) * sycl::range<3>(1, 1, 32), sycl::range<3>(1, 1, 32)),
[=](sycl::nd_item<3> item_ct1) {
[=](sycl::nd_item<3> /*item_ct1*/) {
dequantize_block_nvfp4(vx, y, k);
});
}